@@ -1,37 +1,6 @@
 """
-*********************************************************************************************************
-:copyright (c) BuildingSync®, Copyright (c) 2015-2021, Alliance for Sustainable Energy, LLC,
-and other contributors.
-
-All rights reserved.
-
-Redistribution and use in source and binary forms, with or without modification, are permitted
-provided that the following conditions are met:
-
-(1) Redistributions of source code must retain the above copyright notice, this list of conditions
-and the following disclaimer.
-
-(2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-and the following disclaimer in the documentation and/or other materials provided with the distribution.
-
-(3) Neither the name of the copyright holder nor the names of any contributors may be used to endorse
-or promote products derived from this software without specific prior written permission from the
-respective party.
-
-(4) Other than as required in clauses (1) and (2), distributions in any form of modifications or other
-derivative works may not use the "BuildingSync" trademark or any other confusingly similar designation
-without specific prior written permission from Alliance for Sustainable Energy, LLC.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER(S) AND ANY CONTRIBUTORS "AS IS" AND ANY EXPRESS OR
-IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
-FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER(S), ANY
-CONTRIBUTORS, THE UNITED STATES GOVERNMENT, OR THE UNITED STATES DEPARTMENT OF ENERGY, NOR ANY OF
-THEIR EMPLOYEES, BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
-OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
-STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*********************************************************************************************************
+BuildingSync®, Copyright (c) Alliance for Sustainable Energy, LLC, and other contributors.
+See also https://github.com/BuildingSync/TestSuite/blob/main/LICENSE.txt
 """
 
 import os
@@ -43,45 +12,49 @@ from testsuite.validate_sch import validate_schematron
 
 @pytest.fixture
 def simple_valid_doc_content():
-    return '''<root>
+    return """<root>
         <child attr="hello"/>
-    </root>'''
+    </root>"""
 
 
 @pytest.fixture
 def simple_bad_doc_content():
-    return '''<root>
+    return """<root>
         <child attr="world"/>
-    </root>'''
+    </root>"""
 
 
 @pytest.fixture
 def simple_sch_content():
-    return '''
+    return """
     <sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
         <sch:pattern>
             <sch:rule context="/root/child">
                 <sch:assert test="@attr = 'hello'" role="ERROR">Attr should be hello</sch:assert>
             </sch:rule>
         </sch:pattern>
-    </sch:schema>'''
+    </sch:schema>"""
 
 
 class TestValidateSchematron:
-    def test_when_doc_is_valid_returns_no_errors(self, simple_valid_doc_content, simple_sch_content):
+    def test_when_doc_is_valid_returns_no_errors(
+        self, simple_valid_doc_content, simple_sch_content
+    ):
         # -- Act
         failures = validate_schematron(simple_sch_content, simple_valid_doc_content)
 
         # -- Assert
         assert len(failures) == 0
 
-    def test_accepts_file_path(self, tmpdir, simple_valid_doc_content, simple_sch_content):
+    def test_accepts_file_path(
+        self, tmpdir, simple_valid_doc_content, simple_sch_content
+    ):
         # -- Setup
         doc = os.path.join(tmpdir, "test.xml")
-        with open(doc, 'w') as f:
+        with open(doc, "w") as f:
             f.write(simple_valid_doc_content)
         sch = os.path.join(tmpdir, "test.sch")
-        with open(sch, 'w') as f:
+        with open(sch, "w") as f:
             f.write(simple_sch_content)
 
         # -- Act
@@ -90,7 +63,9 @@ class TestValidateSchematron:
         # -- Assert
         assert len(failures) == 0
 
-    def test_when_doc_is_bad_returns_errors(self, simple_bad_doc_content, simple_sch_content):
+    def test_when_doc_is_bad_returns_errors(
+        self, simple_bad_doc_content, simple_sch_content
+    ):
         # -- Act
         failures = validate_schematron(simple_sch_content, simple_bad_doc_content)
 
@@ -98,17 +73,17 @@ class TestValidateSchematron:
         assert len(failures) == 1
         failure = failures[0]
         assert failure.line == 2
-        assert failure.element == 'child'
-        assert failure.message == 'Attr should be hello'
-        assert failure.role == 'ERROR'
+        assert failure.element == "child"
+        assert failure.message == "Attr should be hello"
+        assert failure.role == "ERROR"
 
     def test_when_phase_is_unspecified_it_runs_all_phases(self):
         # -- Setup
-        doc = '''<root>
+        doc = """<root>
             <child attr="world"/>
-        </root>'''
+        </root>"""
         # create sch that uses phases - each of which should fail against the document
-        sch = '''<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
+        sch = """<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
             <sch:phase id="phaseA">
                 <sch:active pattern="patternA"/>
             </sch:phase>
@@ -125,7 +100,7 @@ class TestValidateSchematron:
                     <sch:assert test="count(child) = 123" role="ERROR">There should be 123 child elements</sch:assert>
                 </sch:rule>
             </sch:pattern>
-        </sch:schema>'''
+        </sch:schema>"""
 
         # -- Act
         failures = validate_schematron(sch, doc)
@@ -135,11 +110,11 @@ class TestValidateSchematron:
 
     def test_when_phase_is_specified_it_runs_only_that_phase(self):
         # -- Setup
-        doc = '''<root>
+        doc = """<root>
             <child attr="world"/>
-        </root>'''
+        </root>"""
         # create sch that uses phases - each of which should fail against the document
-        sch = '''<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
+        sch = """<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
             <sch:phase id="phaseA">
                 <sch:active pattern="patternA"/>
             </sch:phase>
@@ -156,7 +131,7 @@ class TestValidateSchematron:
                     <sch:assert test="count(child) = 123" role="ERROR">There should be 123 child elements</sch:assert>
                 </sch:rule>
             </sch:pattern>
-        </sch:schema>'''
+        </sch:schema>"""
 
         # -- Act
         # note that we are passing a phase ID in order to only run that one
@@ -165,15 +140,17 @@ class TestValidateSchematron:
         # -- Assert
         # there should only be one failure b/c we only ran one phase
         assert len(failures) == 1
-        assert failures[0].message == 'Attr should be hello'
+        assert failures[0].message == "Attr should be hello"
 
-    def test_when_phase_is_specified_and_using_strict_context_it_ignores_rules_in_phases_not_run(self):
+    def test_when_phase_is_specified_and_using_strict_context_it_ignores_rules_in_phases_not_run(
+        self,
+    ):
         # -- Setup
-        doc = '''<root>
+        doc = """<root>
             <child attr="world"/>
-        </root>'''
+        </root>"""
         # create sch that uses phases - each of which should fail against the document
-        sch = '''<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
+        sch = """<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
             <sch:phase id="phaseA">
                 <sch:active pattern="patternA"/>
             </sch:phase>
@@ -190,7 +167,7 @@ class TestValidateSchematron:
                     <sch:assert test="count(child) = 123" role="ERROR">There should be 123 child elements</sch:assert>
                 </sch:rule>
             </sch:pattern>
-        </sch:schema>'''
+        </sch:schema>"""
 
         # -- Act
         # note that we are passing a phase ID in order to only run that one
@@ -199,15 +176,15 @@ class TestValidateSchematron:
         # -- Assert
         # there should only be one failure b/c we only ran one phase
         assert len(failures) == 1
-        assert failures[0].message == 'Attr should be hello'
+        assert failures[0].message == "Attr should be hello"
 
     def test_when_phase_is_specified_and_it_does_not_exist_validation_fails(self):
         # -- Setup
-        doc = '''<root>
+        doc = """<root>
             <child attr="world"/>
-        </root>'''
+        </root>"""
         # create sch that uses phases - each of which should fail against the document
-        sch = '''<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
+        sch = """<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
             <sch:phase id="phaseA">
                 <sch:active pattern="patternA"/>
             </sch:phase>
@@ -216,20 +193,20 @@ class TestValidateSchematron:
                     <sch:assert test="@attr = 'hello'" role="ERROR">Attr should be hello</sch:assert>
                 </sch:rule>
             </sch:pattern>
-        </sch:schema>'''
+        </sch:schema>"""
 
         # -- Act, Assert
         with pytest.raises(Exception):
-            validate_schematron(sch, doc, phase='bogus_phase_id')
+            validate_schematron(sch, doc, phase="bogus_phase_id")
 
     def test_when_using_strict_context_it_returns_failures_for_unfired_rules(self):
         # -- Setup
-        doc = '''<root>
+        doc = """<root>
             <child attr="hello"/>
-        </root>'''
+        </root>"""
         # first pattern should fire and pass
         # second pattern should _not_fire, and with strict validation result in a failure
-        sch = '''<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
+        sch = """<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron">
             <sch:pattern id="patternA">
                 <sch:rule context="/root/child">
                     <sch:assert test="@attr = 'hello'" role="ERROR">Attr should be hello</sch:assert>
@@ -240,7 +217,7 @@ class TestValidateSchematron:
                     <sch:assert test="count(fake) = 123" role="ERROR">There should be 123 fake elements</sch:assert>
                 </sch:rule>
             </sch:pattern>
-        </sch:schema>'''
+        </sch:schema>"""
 
         # -- Act
         failures = validate_schematron(sch, doc, strict_context=True)
@@ -248,4 +225,4 @@ class TestValidateSchematron:
         # -- Assert
         # there should be one failure, the rule which was not fired
         assert len(failures) == 1
-        assert failures[0].message == 'Rule was NOT used for validation: /root/bogus'
+        assert failures[0].message == "Rule was NOT used for validation: /root/bogus"
